@@ -270,7 +270,9 @@ class FireboltDialect(default.DefaultDialect):
         parameters: Tuple[str, Any],
         context: Optional[ExecutionContext] = None,
     ) -> None:
-        cursor.execute(statement, set_parameters=self._set_parameters)
+        cursor.execute(
+            statement, parameters=parameters, set_parameters=self._set_parameters
+        )
 
     def do_rollback(self, dbapi_connection: AlchemyConnection) -> None:
         pass
@@ -300,5 +302,5 @@ class FireboltDialect(default.DefaultDialect):
 dialect = FireboltDialect
 
 
-def get_is_nullable(column_is_nullable: str) -> bool:
-    return column_is_nullable.lower() == "yes"
+def get_is_nullable(column_is_nullable: int) -> bool:
+    return column_is_nullable == 1
